@@ -25,7 +25,8 @@ def Spec(name: str, filename: str = 'main.py', icon: str = '', path: str = os.ge
 
     path = path.replace("\\", r"\\")
 
-    print(fr"""
+    with open(filename.replace('.py', '.spec'), 'w') as f:
+        f.write(fr"""
 from kivy_deps import sdl2, glew
 
 # -*- mode: python ; coding: utf-8 -*-
@@ -34,7 +35,7 @@ from kivy_deps import sdl2, glew
 block_cipher = None
 
 a = Analysis(['{filename}'],
-             pathex=[{path}],
+             pathex=['{path}'],
              binaries=[],
              datas=[],
              hiddenimports=[],
